// This file was generated by qtwaylandscanner
// source file is color-management-v1.xml

#include "qwayland-color-management-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    wp_color_manager_v1::wp_color_manager_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_color_manager_v1::wp_color_manager_v1(struct ::wp_color_manager_v1 *obj)
        : m_wp_color_manager_v1(obj)
    {
        init_listener();
    }

    wp_color_manager_v1::wp_color_manager_v1()
        : m_wp_color_manager_v1(nullptr)
    {
    }

    wp_color_manager_v1::~wp_color_manager_v1()
    {
    }

    void wp_color_manager_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_color_manager_v1 = static_cast<struct ::wp_color_manager_v1 *>(wlRegistryBind(registry, id, &wp_color_manager_v1_interface, version));
        init_listener();
    }

    void wp_color_manager_v1::init(struct ::wp_color_manager_v1 *obj)
    {
        m_wp_color_manager_v1 = obj;
        init_listener();
    }

    wp_color_manager_v1 *wp_color_manager_v1::fromObject(struct ::wp_color_manager_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_wp_color_manager_v1_listener)
            return nullptr;
        return static_cast<wp_color_manager_v1 *>(wp_color_manager_v1_get_user_data(object));
    }

    bool wp_color_manager_v1::isInitialized() const
    {
        return m_wp_color_manager_v1 != nullptr;
    }

    uint32_t wp_color_manager_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_color_manager_v1));
    }

    const struct wl_interface *wp_color_manager_v1::interface()
    {
        return &::wp_color_manager_v1_interface;
    }

    void wp_color_manager_v1::destroy()
    {
        ::wp_color_manager_v1_destroy(
            m_wp_color_manager_v1);
        m_wp_color_manager_v1 = nullptr;
    }

    struct ::wp_color_management_output_v1 *wp_color_manager_v1::get_output(struct ::wl_output *output)
    {
        struct ::wp_color_management_output_v1 * id = ::wp_color_manager_v1_get_output(
            m_wp_color_manager_v1,
            output);
        return id;
    }

    struct ::wp_color_management_surface_v1 *wp_color_manager_v1::get_surface(struct ::wl_surface *surface)
    {
        struct ::wp_color_management_surface_v1 * id = ::wp_color_manager_v1_get_surface(
            m_wp_color_manager_v1,
            surface);
        return id;
    }

    struct ::wp_color_management_surface_feedback_v1 *wp_color_manager_v1::get_surface_feedback(struct ::wl_surface *surface)
    {
        struct ::wp_color_management_surface_feedback_v1 * id = ::wp_color_manager_v1_get_surface_feedback(
            m_wp_color_manager_v1,
            surface);
        return id;
    }

    struct ::wp_image_description_creator_icc_v1 *wp_color_manager_v1::create_icc_creator()
    {
        struct ::wp_image_description_creator_icc_v1 * obj = ::wp_color_manager_v1_create_icc_creator(
            m_wp_color_manager_v1);
        return obj;
    }

    struct ::wp_image_description_creator_params_v1 *wp_color_manager_v1::create_parametric_creator()
    {
        struct ::wp_image_description_creator_params_v1 * obj = ::wp_color_manager_v1_create_parametric_creator(
            m_wp_color_manager_v1);
        return obj;
    }

    struct ::wp_image_description_v1 *wp_color_manager_v1::create_windows_scrgb()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_manager_v1_create_windows_scrgb(
            m_wp_color_manager_v1);
        return image_description;
    }

    struct ::wp_image_description_v1 *wp_color_manager_v1::get_image_description(struct ::wp_image_description_reference_v1 *reference)
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_manager_v1_get_image_description(
            m_wp_color_manager_v1,
            reference);
        return image_description;
    }

    struct ::wp_image_description_v1 *wp_color_manager_v1::create_windows_bt2100()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_manager_v1_create_windows_bt2100(
            m_wp_color_manager_v1);
        return image_description;
    }

    void wp_color_manager_v1::wp_color_manager_v1_supported_intent(uint32_t )
    {
    }

    void wp_color_manager_v1::handle_supported_intent(
        void *data,
        struct ::wp_color_manager_v1 *object,
        uint32_t render_intent)
    {
        Q_UNUSED(object);
        static_cast<wp_color_manager_v1 *>(data)->wp_color_manager_v1_supported_intent(
            render_intent);
    }

    void wp_color_manager_v1::wp_color_manager_v1_supported_feature(uint32_t )
    {
    }

    void wp_color_manager_v1::handle_supported_feature(
        void *data,
        struct ::wp_color_manager_v1 *object,
        uint32_t feature)
    {
        Q_UNUSED(object);
        static_cast<wp_color_manager_v1 *>(data)->wp_color_manager_v1_supported_feature(
            feature);
    }

    void wp_color_manager_v1::wp_color_manager_v1_supported_tf_named(uint32_t )
    {
    }

    void wp_color_manager_v1::handle_supported_tf_named(
        void *data,
        struct ::wp_color_manager_v1 *object,
        uint32_t tf)
    {
        Q_UNUSED(object);
        static_cast<wp_color_manager_v1 *>(data)->wp_color_manager_v1_supported_tf_named(
            tf);
    }

    void wp_color_manager_v1::wp_color_manager_v1_supported_primaries_named(uint32_t )
    {
    }

    void wp_color_manager_v1::handle_supported_primaries_named(
        void *data,
        struct ::wp_color_manager_v1 *object,
        uint32_t primaries)
    {
        Q_UNUSED(object);
        static_cast<wp_color_manager_v1 *>(data)->wp_color_manager_v1_supported_primaries_named(
            primaries);
    }

    void wp_color_manager_v1::wp_color_manager_v1_done()
    {
    }

    void wp_color_manager_v1::handle_done(
        void *data,
        struct ::wp_color_manager_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<wp_color_manager_v1 *>(data)->wp_color_manager_v1_done();
    }

    const struct wp_color_manager_v1_listener wp_color_manager_v1::m_wp_color_manager_v1_listener = {
        wp_color_manager_v1::handle_supported_intent,
        wp_color_manager_v1::handle_supported_feature,
        wp_color_manager_v1::handle_supported_tf_named,
        wp_color_manager_v1::handle_supported_primaries_named,
        wp_color_manager_v1::handle_done,
    };

    void wp_color_manager_v1::init_listener()
    {
        wp_color_manager_v1_add_listener(m_wp_color_manager_v1, &m_wp_color_manager_v1_listener, this);
    }

    wp_color_management_output_v1::wp_color_management_output_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_color_management_output_v1::wp_color_management_output_v1(struct ::wp_color_management_output_v1 *obj)
        : m_wp_color_management_output_v1(obj)
    {
        init_listener();
    }

    wp_color_management_output_v1::wp_color_management_output_v1()
        : m_wp_color_management_output_v1(nullptr)
    {
    }

    wp_color_management_output_v1::~wp_color_management_output_v1()
    {
    }

    void wp_color_management_output_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_color_management_output_v1 = static_cast<struct ::wp_color_management_output_v1 *>(wlRegistryBind(registry, id, &wp_color_management_output_v1_interface, version));
        init_listener();
    }

    void wp_color_management_output_v1::init(struct ::wp_color_management_output_v1 *obj)
    {
        m_wp_color_management_output_v1 = obj;
        init_listener();
    }

    wp_color_management_output_v1 *wp_color_management_output_v1::fromObject(struct ::wp_color_management_output_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_wp_color_management_output_v1_listener)
            return nullptr;
        return static_cast<wp_color_management_output_v1 *>(wp_color_management_output_v1_get_user_data(object));
    }

    bool wp_color_management_output_v1::isInitialized() const
    {
        return m_wp_color_management_output_v1 != nullptr;
    }

    uint32_t wp_color_management_output_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_color_management_output_v1));
    }

    const struct wl_interface *wp_color_management_output_v1::interface()
    {
        return &::wp_color_management_output_v1_interface;
    }

    void wp_color_management_output_v1::destroy()
    {
        ::wp_color_management_output_v1_destroy(
            m_wp_color_management_output_v1);
        m_wp_color_management_output_v1 = nullptr;
    }

    struct ::wp_image_description_v1 *wp_color_management_output_v1::get_image_description()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_management_output_v1_get_image_description(
            m_wp_color_management_output_v1);
        return image_description;
    }

    void wp_color_management_output_v1::wp_color_management_output_v1_image_description_changed()
    {
    }

    void wp_color_management_output_v1::handle_image_description_changed(
        void *data,
        struct ::wp_color_management_output_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<wp_color_management_output_v1 *>(data)->wp_color_management_output_v1_image_description_changed();
    }

    const struct wp_color_management_output_v1_listener wp_color_management_output_v1::m_wp_color_management_output_v1_listener = {
        wp_color_management_output_v1::handle_image_description_changed,
    };

    void wp_color_management_output_v1::init_listener()
    {
        wp_color_management_output_v1_add_listener(m_wp_color_management_output_v1, &m_wp_color_management_output_v1_listener, this);
    }

    wp_color_management_surface_v1::wp_color_management_surface_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_color_management_surface_v1::wp_color_management_surface_v1(struct ::wp_color_management_surface_v1 *obj)
        : m_wp_color_management_surface_v1(obj)
    {
    }

    wp_color_management_surface_v1::wp_color_management_surface_v1()
        : m_wp_color_management_surface_v1(nullptr)
    {
    }

    wp_color_management_surface_v1::~wp_color_management_surface_v1()
    {
    }

    void wp_color_management_surface_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_color_management_surface_v1 = static_cast<struct ::wp_color_management_surface_v1 *>(wlRegistryBind(registry, id, &wp_color_management_surface_v1_interface, version));
    }

    void wp_color_management_surface_v1::init(struct ::wp_color_management_surface_v1 *obj)
    {
        m_wp_color_management_surface_v1 = obj;
    }

    wp_color_management_surface_v1 *wp_color_management_surface_v1::fromObject(struct ::wp_color_management_surface_v1 *object)
    {
        return static_cast<wp_color_management_surface_v1 *>(wp_color_management_surface_v1_get_user_data(object));
    }

    bool wp_color_management_surface_v1::isInitialized() const
    {
        return m_wp_color_management_surface_v1 != nullptr;
    }

    uint32_t wp_color_management_surface_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_color_management_surface_v1));
    }

    const struct wl_interface *wp_color_management_surface_v1::interface()
    {
        return &::wp_color_management_surface_v1_interface;
    }

    void wp_color_management_surface_v1::destroy()
    {
        ::wp_color_management_surface_v1_destroy(
            m_wp_color_management_surface_v1);
        m_wp_color_management_surface_v1 = nullptr;
    }

    void wp_color_management_surface_v1::set_image_description(struct ::wp_image_description_v1 *image_description, uint32_t render_intent)
    {
        ::wp_color_management_surface_v1_set_image_description(
            m_wp_color_management_surface_v1,
            image_description,
            render_intent);
    }

    void wp_color_management_surface_v1::unset_image_description()
    {
        ::wp_color_management_surface_v1_unset_image_description(
            m_wp_color_management_surface_v1);
    }

    wp_color_management_surface_feedback_v1::wp_color_management_surface_feedback_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_color_management_surface_feedback_v1::wp_color_management_surface_feedback_v1(struct ::wp_color_management_surface_feedback_v1 *obj)
        : m_wp_color_management_surface_feedback_v1(obj)
    {
        init_listener();
    }

    wp_color_management_surface_feedback_v1::wp_color_management_surface_feedback_v1()
        : m_wp_color_management_surface_feedback_v1(nullptr)
    {
    }

    wp_color_management_surface_feedback_v1::~wp_color_management_surface_feedback_v1()
    {
    }

    void wp_color_management_surface_feedback_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_color_management_surface_feedback_v1 = static_cast<struct ::wp_color_management_surface_feedback_v1 *>(wlRegistryBind(registry, id, &wp_color_management_surface_feedback_v1_interface, version));
        init_listener();
    }

    void wp_color_management_surface_feedback_v1::init(struct ::wp_color_management_surface_feedback_v1 *obj)
    {
        m_wp_color_management_surface_feedback_v1 = obj;
        init_listener();
    }

    wp_color_management_surface_feedback_v1 *wp_color_management_surface_feedback_v1::fromObject(struct ::wp_color_management_surface_feedback_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_wp_color_management_surface_feedback_v1_listener)
            return nullptr;
        return static_cast<wp_color_management_surface_feedback_v1 *>(wp_color_management_surface_feedback_v1_get_user_data(object));
    }

    bool wp_color_management_surface_feedback_v1::isInitialized() const
    {
        return m_wp_color_management_surface_feedback_v1 != nullptr;
    }

    uint32_t wp_color_management_surface_feedback_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_color_management_surface_feedback_v1));
    }

    const struct wl_interface *wp_color_management_surface_feedback_v1::interface()
    {
        return &::wp_color_management_surface_feedback_v1_interface;
    }

    void wp_color_management_surface_feedback_v1::destroy()
    {
        ::wp_color_management_surface_feedback_v1_destroy(
            m_wp_color_management_surface_feedback_v1);
        m_wp_color_management_surface_feedback_v1 = nullptr;
    }

    struct ::wp_image_description_v1 *wp_color_management_surface_feedback_v1::get_preferred()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_management_surface_feedback_v1_get_preferred(
            m_wp_color_management_surface_feedback_v1);
        return image_description;
    }

    struct ::wp_image_description_v1 *wp_color_management_surface_feedback_v1::get_preferred_parametric()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_color_management_surface_feedback_v1_get_preferred_parametric(
            m_wp_color_management_surface_feedback_v1);
        return image_description;
    }

    void wp_color_management_surface_feedback_v1::wp_color_management_surface_feedback_v1_preferred_changed(uint32_t )
    {
    }

    void wp_color_management_surface_feedback_v1::handle_preferred_changed(
        void *data,
        struct ::wp_color_management_surface_feedback_v1 *object,
        uint32_t identity)
    {
        Q_UNUSED(object);
        static_cast<wp_color_management_surface_feedback_v1 *>(data)->wp_color_management_surface_feedback_v1_preferred_changed(
            identity);
    }

    void wp_color_management_surface_feedback_v1::wp_color_management_surface_feedback_v1_preferred_changed2(uint32_t , uint32_t )
    {
    }

    void wp_color_management_surface_feedback_v1::handle_preferred_changed2(
        void *data,
        struct ::wp_color_management_surface_feedback_v1 *object,
        uint32_t identity_hi,
        uint32_t identity_lo)
    {
        Q_UNUSED(object);
        static_cast<wp_color_management_surface_feedback_v1 *>(data)->wp_color_management_surface_feedback_v1_preferred_changed2(
            identity_hi,
            identity_lo);
    }

    const struct wp_color_management_surface_feedback_v1_listener wp_color_management_surface_feedback_v1::m_wp_color_management_surface_feedback_v1_listener = {
        wp_color_management_surface_feedback_v1::handle_preferred_changed,
        wp_color_management_surface_feedback_v1::handle_preferred_changed2,
    };

    void wp_color_management_surface_feedback_v1::init_listener()
    {
        wp_color_management_surface_feedback_v1_add_listener(m_wp_color_management_surface_feedback_v1, &m_wp_color_management_surface_feedback_v1_listener, this);
    }

    wp_image_description_creator_icc_v1::wp_image_description_creator_icc_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_image_description_creator_icc_v1::wp_image_description_creator_icc_v1(struct ::wp_image_description_creator_icc_v1 *obj)
        : m_wp_image_description_creator_icc_v1(obj)
    {
    }

    wp_image_description_creator_icc_v1::wp_image_description_creator_icc_v1()
        : m_wp_image_description_creator_icc_v1(nullptr)
    {
    }

    wp_image_description_creator_icc_v1::~wp_image_description_creator_icc_v1()
    {
    }

    void wp_image_description_creator_icc_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_image_description_creator_icc_v1 = static_cast<struct ::wp_image_description_creator_icc_v1 *>(wlRegistryBind(registry, id, &wp_image_description_creator_icc_v1_interface, version));
    }

    void wp_image_description_creator_icc_v1::init(struct ::wp_image_description_creator_icc_v1 *obj)
    {
        m_wp_image_description_creator_icc_v1 = obj;
    }

    wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1::fromObject(struct ::wp_image_description_creator_icc_v1 *object)
    {
        return static_cast<wp_image_description_creator_icc_v1 *>(wp_image_description_creator_icc_v1_get_user_data(object));
    }

    bool wp_image_description_creator_icc_v1::isInitialized() const
    {
        return m_wp_image_description_creator_icc_v1 != nullptr;
    }

    uint32_t wp_image_description_creator_icc_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_image_description_creator_icc_v1));
    }

    const struct wl_interface *wp_image_description_creator_icc_v1::interface()
    {
        return &::wp_image_description_creator_icc_v1_interface;
    }

    struct ::wp_image_description_v1 *wp_image_description_creator_icc_v1::create()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_image_description_creator_icc_v1_create(
            m_wp_image_description_creator_icc_v1);
        m_wp_image_description_creator_icc_v1 = nullptr;
        return image_description;
    }

    void wp_image_description_creator_icc_v1::set_icc_file(int32_t icc_profile, uint32_t offset, uint32_t length)
    {
        ::wp_image_description_creator_icc_v1_set_icc_file(
            m_wp_image_description_creator_icc_v1,
            icc_profile,
            offset,
            length);
    }

    wp_image_description_creator_params_v1::wp_image_description_creator_params_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_image_description_creator_params_v1::wp_image_description_creator_params_v1(struct ::wp_image_description_creator_params_v1 *obj)
        : m_wp_image_description_creator_params_v1(obj)
    {
    }

    wp_image_description_creator_params_v1::wp_image_description_creator_params_v1()
        : m_wp_image_description_creator_params_v1(nullptr)
    {
    }

    wp_image_description_creator_params_v1::~wp_image_description_creator_params_v1()
    {
    }

    void wp_image_description_creator_params_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_image_description_creator_params_v1 = static_cast<struct ::wp_image_description_creator_params_v1 *>(wlRegistryBind(registry, id, &wp_image_description_creator_params_v1_interface, version));
    }

    void wp_image_description_creator_params_v1::init(struct ::wp_image_description_creator_params_v1 *obj)
    {
        m_wp_image_description_creator_params_v1 = obj;
    }

    wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1::fromObject(struct ::wp_image_description_creator_params_v1 *object)
    {
        return static_cast<wp_image_description_creator_params_v1 *>(wp_image_description_creator_params_v1_get_user_data(object));
    }

    bool wp_image_description_creator_params_v1::isInitialized() const
    {
        return m_wp_image_description_creator_params_v1 != nullptr;
    }

    uint32_t wp_image_description_creator_params_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_image_description_creator_params_v1));
    }

    const struct wl_interface *wp_image_description_creator_params_v1::interface()
    {
        return &::wp_image_description_creator_params_v1_interface;
    }

    struct ::wp_image_description_v1 *wp_image_description_creator_params_v1::create()
    {
        struct ::wp_image_description_v1 * image_description = ::wp_image_description_creator_params_v1_create(
            m_wp_image_description_creator_params_v1);
        m_wp_image_description_creator_params_v1 = nullptr;
        return image_description;
    }

    void wp_image_description_creator_params_v1::set_tf_named(uint32_t tf)
    {
        ::wp_image_description_creator_params_v1_set_tf_named(
            m_wp_image_description_creator_params_v1,
            tf);
    }

    void wp_image_description_creator_params_v1::set_tf_power(uint32_t eexp)
    {
        ::wp_image_description_creator_params_v1_set_tf_power(
            m_wp_image_description_creator_params_v1,
            eexp);
    }

    void wp_image_description_creator_params_v1::set_primaries_named(uint32_t primaries)
    {
        ::wp_image_description_creator_params_v1_set_primaries_named(
            m_wp_image_description_creator_params_v1,
            primaries);
    }

    void wp_image_description_creator_params_v1::set_primaries(int32_t r_x, int32_t r_y, int32_t g_x, int32_t g_y, int32_t b_x, int32_t b_y, int32_t w_x, int32_t w_y)
    {
        ::wp_image_description_creator_params_v1_set_primaries(
            m_wp_image_description_creator_params_v1,
            r_x,
            r_y,
            g_x,
            g_y,
            b_x,
            b_y,
            w_x,
            w_y);
    }

    void wp_image_description_creator_params_v1::set_luminances(uint32_t min_lum, uint32_t max_lum, uint32_t reference_lum)
    {
        ::wp_image_description_creator_params_v1_set_luminances(
            m_wp_image_description_creator_params_v1,
            min_lum,
            max_lum,
            reference_lum);
    }

    void wp_image_description_creator_params_v1::set_mastering_display_primaries(int32_t r_x, int32_t r_y, int32_t g_x, int32_t g_y, int32_t b_x, int32_t b_y, int32_t w_x, int32_t w_y)
    {
        ::wp_image_description_creator_params_v1_set_mastering_display_primaries(
            m_wp_image_description_creator_params_v1,
            r_x,
            r_y,
            g_x,
            g_y,
            b_x,
            b_y,
            w_x,
            w_y);
    }

    void wp_image_description_creator_params_v1::set_mastering_luminance(uint32_t min_lum, uint32_t max_lum)
    {
        ::wp_image_description_creator_params_v1_set_mastering_luminance(
            m_wp_image_description_creator_params_v1,
            min_lum,
            max_lum);
    }

    void wp_image_description_creator_params_v1::set_max_cll(uint32_t max_cll)
    {
        ::wp_image_description_creator_params_v1_set_max_cll(
            m_wp_image_description_creator_params_v1,
            max_cll);
    }

    void wp_image_description_creator_params_v1::set_max_fall(uint32_t max_fall)
    {
        ::wp_image_description_creator_params_v1_set_max_fall(
            m_wp_image_description_creator_params_v1,
            max_fall);
    }

    wp_image_description_v1::wp_image_description_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_image_description_v1::wp_image_description_v1(struct ::wp_image_description_v1 *obj)
        : m_wp_image_description_v1(obj)
    {
        init_listener();
    }

    wp_image_description_v1::wp_image_description_v1()
        : m_wp_image_description_v1(nullptr)
    {
    }

    wp_image_description_v1::~wp_image_description_v1()
    {
    }

    void wp_image_description_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_image_description_v1 = static_cast<struct ::wp_image_description_v1 *>(wlRegistryBind(registry, id, &wp_image_description_v1_interface, version));
        init_listener();
    }

    void wp_image_description_v1::init(struct ::wp_image_description_v1 *obj)
    {
        m_wp_image_description_v1 = obj;
        init_listener();
    }

    wp_image_description_v1 *wp_image_description_v1::fromObject(struct ::wp_image_description_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_wp_image_description_v1_listener)
            return nullptr;
        return static_cast<wp_image_description_v1 *>(wp_image_description_v1_get_user_data(object));
    }

    bool wp_image_description_v1::isInitialized() const
    {
        return m_wp_image_description_v1 != nullptr;
    }

    uint32_t wp_image_description_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_image_description_v1));
    }

    const struct wl_interface *wp_image_description_v1::interface()
    {
        return &::wp_image_description_v1_interface;
    }

    void wp_image_description_v1::destroy()
    {
        ::wp_image_description_v1_destroy(
            m_wp_image_description_v1);
        m_wp_image_description_v1 = nullptr;
    }

    struct ::wp_image_description_info_v1 *wp_image_description_v1::get_information()
    {
        struct ::wp_image_description_info_v1 * information = ::wp_image_description_v1_get_information(
            m_wp_image_description_v1);
        return information;
    }

    void wp_image_description_v1::wp_image_description_v1_failed(uint32_t , const QString &)
    {
    }

    void wp_image_description_v1::handle_failed(
        void *data,
        struct ::wp_image_description_v1 *object,
        uint32_t cause,
        const char *msg)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_v1 *>(data)->wp_image_description_v1_failed(
            cause,
            QString::fromUtf8(msg));
    }

    void wp_image_description_v1::wp_image_description_v1_ready(uint32_t )
    {
    }

    void wp_image_description_v1::handle_ready(
        void *data,
        struct ::wp_image_description_v1 *object,
        uint32_t identity)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_v1 *>(data)->wp_image_description_v1_ready(
            identity);
    }

    void wp_image_description_v1::wp_image_description_v1_ready2(uint32_t , uint32_t )
    {
    }

    void wp_image_description_v1::handle_ready2(
        void *data,
        struct ::wp_image_description_v1 *object,
        uint32_t identity_hi,
        uint32_t identity_lo)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_v1 *>(data)->wp_image_description_v1_ready2(
            identity_hi,
            identity_lo);
    }

    const struct wp_image_description_v1_listener wp_image_description_v1::m_wp_image_description_v1_listener = {
        wp_image_description_v1::handle_failed,
        wp_image_description_v1::handle_ready,
        wp_image_description_v1::handle_ready2,
    };

    void wp_image_description_v1::init_listener()
    {
        wp_image_description_v1_add_listener(m_wp_image_description_v1, &m_wp_image_description_v1_listener, this);
    }

    wp_image_description_info_v1::wp_image_description_info_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_image_description_info_v1::wp_image_description_info_v1(struct ::wp_image_description_info_v1 *obj)
        : m_wp_image_description_info_v1(obj)
    {
        init_listener();
    }

    wp_image_description_info_v1::wp_image_description_info_v1()
        : m_wp_image_description_info_v1(nullptr)
    {
    }

    wp_image_description_info_v1::~wp_image_description_info_v1()
    {
    }

    void wp_image_description_info_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_image_description_info_v1 = static_cast<struct ::wp_image_description_info_v1 *>(wlRegistryBind(registry, id, &wp_image_description_info_v1_interface, version));
        init_listener();
    }

    void wp_image_description_info_v1::init(struct ::wp_image_description_info_v1 *obj)
    {
        m_wp_image_description_info_v1 = obj;
        init_listener();
    }

    wp_image_description_info_v1 *wp_image_description_info_v1::fromObject(struct ::wp_image_description_info_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_wp_image_description_info_v1_listener)
            return nullptr;
        return static_cast<wp_image_description_info_v1 *>(wp_image_description_info_v1_get_user_data(object));
    }

    bool wp_image_description_info_v1::isInitialized() const
    {
        return m_wp_image_description_info_v1 != nullptr;
    }

    uint32_t wp_image_description_info_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_image_description_info_v1));
    }

    const struct wl_interface *wp_image_description_info_v1::interface()
    {
        return &::wp_image_description_info_v1_interface;
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_done()
    {
    }

    void wp_image_description_info_v1::handle_done(
        void *data,
        struct ::wp_image_description_info_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_done();
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_icc_file(int32_t , uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_icc_file(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        int32_t icc,
        uint32_t icc_size)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_icc_file(
            icc,
            icc_size);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_primaries(int32_t , int32_t , int32_t , int32_t , int32_t , int32_t , int32_t , int32_t )
    {
    }

    void wp_image_description_info_v1::handle_primaries(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        int32_t r_x,
        int32_t r_y,
        int32_t g_x,
        int32_t g_y,
        int32_t b_x,
        int32_t b_y,
        int32_t w_x,
        int32_t w_y)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_primaries(
            r_x,
            r_y,
            g_x,
            g_y,
            b_x,
            b_y,
            w_x,
            w_y);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_primaries_named(uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_primaries_named(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t primaries)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_primaries_named(
            primaries);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_tf_power(uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_tf_power(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t eexp)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_tf_power(
            eexp);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_tf_named(uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_tf_named(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t tf)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_tf_named(
            tf);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_luminances(uint32_t , uint32_t , uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_luminances(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t min_lum,
        uint32_t max_lum,
        uint32_t reference_lum)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_luminances(
            min_lum,
            max_lum,
            reference_lum);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_target_primaries(int32_t , int32_t , int32_t , int32_t , int32_t , int32_t , int32_t , int32_t )
    {
    }

    void wp_image_description_info_v1::handle_target_primaries(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        int32_t r_x,
        int32_t r_y,
        int32_t g_x,
        int32_t g_y,
        int32_t b_x,
        int32_t b_y,
        int32_t w_x,
        int32_t w_y)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_target_primaries(
            r_x,
            r_y,
            g_x,
            g_y,
            b_x,
            b_y,
            w_x,
            w_y);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_target_luminance(uint32_t , uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_target_luminance(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t min_lum,
        uint32_t max_lum)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_target_luminance(
            min_lum,
            max_lum);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_target_max_cll(uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_target_max_cll(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t max_cll)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_target_max_cll(
            max_cll);
    }

    void wp_image_description_info_v1::wp_image_description_info_v1_target_max_fall(uint32_t )
    {
    }

    void wp_image_description_info_v1::handle_target_max_fall(
        void *data,
        struct ::wp_image_description_info_v1 *object,
        uint32_t max_fall)
    {
        Q_UNUSED(object);
        static_cast<wp_image_description_info_v1 *>(data)->wp_image_description_info_v1_target_max_fall(
            max_fall);
    }

    const struct wp_image_description_info_v1_listener wp_image_description_info_v1::m_wp_image_description_info_v1_listener = {
        wp_image_description_info_v1::handle_done,
        wp_image_description_info_v1::handle_icc_file,
        wp_image_description_info_v1::handle_primaries,
        wp_image_description_info_v1::handle_primaries_named,
        wp_image_description_info_v1::handle_tf_power,
        wp_image_description_info_v1::handle_tf_named,
        wp_image_description_info_v1::handle_luminances,
        wp_image_description_info_v1::handle_target_primaries,
        wp_image_description_info_v1::handle_target_luminance,
        wp_image_description_info_v1::handle_target_max_cll,
        wp_image_description_info_v1::handle_target_max_fall,
    };

    void wp_image_description_info_v1::init_listener()
    {
        wp_image_description_info_v1_add_listener(m_wp_image_description_info_v1, &m_wp_image_description_info_v1_listener, this);
    }

    wp_image_description_reference_v1::wp_image_description_reference_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    wp_image_description_reference_v1::wp_image_description_reference_v1(struct ::wp_image_description_reference_v1 *obj)
        : m_wp_image_description_reference_v1(obj)
    {
    }

    wp_image_description_reference_v1::wp_image_description_reference_v1()
        : m_wp_image_description_reference_v1(nullptr)
    {
    }

    wp_image_description_reference_v1::~wp_image_description_reference_v1()
    {
    }

    void wp_image_description_reference_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_wp_image_description_reference_v1 = static_cast<struct ::wp_image_description_reference_v1 *>(wlRegistryBind(registry, id, &wp_image_description_reference_v1_interface, version));
    }

    void wp_image_description_reference_v1::init(struct ::wp_image_description_reference_v1 *obj)
    {
        m_wp_image_description_reference_v1 = obj;
    }

    wp_image_description_reference_v1 *wp_image_description_reference_v1::fromObject(struct ::wp_image_description_reference_v1 *object)
    {
        return static_cast<wp_image_description_reference_v1 *>(wp_image_description_reference_v1_get_user_data(object));
    }

    bool wp_image_description_reference_v1::isInitialized() const
    {
        return m_wp_image_description_reference_v1 != nullptr;
    }

    uint32_t wp_image_description_reference_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_wp_image_description_reference_v1));
    }

    const struct wl_interface *wp_image_description_reference_v1::interface()
    {
        return &::wp_image_description_reference_v1_interface;
    }

    void wp_image_description_reference_v1::destroy()
    {
        ::wp_image_description_reference_v1_destroy(
            m_wp_image_description_reference_v1);
        m_wp_image_description_reference_v1 = nullptr;
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
