/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<osdmanager.h>)
#  include <osdmanager.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kscreen_osd()
{
    qmlRegisterModule("org.kde.kscreen.osd", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<KScreen::OsdAction>().id();
    qmlRegisterEnum<KScreen::OsdAction::Action>("KScreen::OsdAction::Action");
    qmlRegisterTypesAndRevisions<KScreen::OsdActionForeign>("org.kde.kscreen.osd", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kscreen.osd", 254, 254);
}

static const QQmlModuleRegistration orgkdekscreenosdRegistration("org.kde.kscreen.osd", qml_register_types_org_kde_kscreen_osd);
