/****************************************************************************
** Meta object code from reading C++ file 'output_model.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreen-6.7.2/kcm/output_model.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'output_model.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11OutputModelE_t {};
} // unnamed namespace

template <> constexpr inline auto OutputModel::qt_create_metaobjectdata<qt_meta_tag_ZN11OutputModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OutputModel",
        "positionChanged",
        "",
        "sizeChanged",
        "OutputRoles",
        "EnabledRole",
        "InternalRole",
        "PriorityRole",
        "SizeRole",
        "PositionRole",
        "NormalizedPositionRole",
        "AutoRotateRole",
        "RotationRole",
        "ScaleRole",
        "ResolutionIndexRole",
        "ResolutionsRole",
        "ResolutionRole",
        "RefreshRateIndexRole",
        "RefreshRatesRole",
        "ReplicationSourceModelRole",
        "ReplicationSourceIndexRole",
        "ReplicasModelRole",
        "CapabilitiesRole",
        "OverscanRole",
        "VrrPolicyRole",
        "RgbRangeRole",
        "IccProfileRole",
        "HdrRole",
        "SdrBrightnessRole",
        "MaxBrightnessRole",
        "SdrGamutWideness",
        "ColorProfileSource",
        "InteractiveMoveRole",
        "BrightnessRole",
        "ColorPowerPreference",
        "DdcCiAllowedRole",
        "MaxBitsPerColorRole",
        "AutomaticMaxBitsPerColorLimitRole",
        "MinSupportedMaxBitsPerColorRole",
        "MaxSupportedMaxBitsPerColorRole",
        "PeakBrightnessOverride",
        "OutputNameRole",
        "EdrPolicyRole",
        "BitsPerColorOptionsPreferEfficiencyRole",
        "BitsPerColorOptionsPreferAccuracyRole",
        "SharpnessRole",
        "AutoBrightnessRole",
        "HdrIccProfileRole",
        "HdrColorProfileSourceRole",
        "AbmLevelRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'OutputRoles'
        QtMocHelpers::EnumData<enum OutputRoles>(4, 4, QMC::EnumFlags{}).add({
            {    5, OutputRoles::EnabledRole },
            {    6, OutputRoles::InternalRole },
            {    7, OutputRoles::PriorityRole },
            {    8, OutputRoles::SizeRole },
            {    9, OutputRoles::PositionRole },
            {   10, OutputRoles::NormalizedPositionRole },
            {   11, OutputRoles::AutoRotateRole },
            {   12, OutputRoles::RotationRole },
            {   13, OutputRoles::ScaleRole },
            {   14, OutputRoles::ResolutionIndexRole },
            {   15, OutputRoles::ResolutionsRole },
            {   16, OutputRoles::ResolutionRole },
            {   17, OutputRoles::RefreshRateIndexRole },
            {   18, OutputRoles::RefreshRatesRole },
            {   19, OutputRoles::ReplicationSourceModelRole },
            {   20, OutputRoles::ReplicationSourceIndexRole },
            {   21, OutputRoles::ReplicasModelRole },
            {   22, OutputRoles::CapabilitiesRole },
            {   23, OutputRoles::OverscanRole },
            {   24, OutputRoles::VrrPolicyRole },
            {   25, OutputRoles::RgbRangeRole },
            {   26, OutputRoles::IccProfileRole },
            {   27, OutputRoles::HdrRole },
            {   28, OutputRoles::SdrBrightnessRole },
            {   29, OutputRoles::MaxBrightnessRole },
            {   30, OutputRoles::SdrGamutWideness },
            {   31, OutputRoles::ColorProfileSource },
            {   32, OutputRoles::InteractiveMoveRole },
            {   33, OutputRoles::BrightnessRole },
            {   34, OutputRoles::ColorPowerPreference },
            {   35, OutputRoles::DdcCiAllowedRole },
            {   36, OutputRoles::MaxBitsPerColorRole },
            {   37, OutputRoles::AutomaticMaxBitsPerColorLimitRole },
            {   38, OutputRoles::MinSupportedMaxBitsPerColorRole },
            {   39, OutputRoles::MaxSupportedMaxBitsPerColorRole },
            {   40, OutputRoles::PeakBrightnessOverride },
            {   41, OutputRoles::OutputNameRole },
            {   42, OutputRoles::EdrPolicyRole },
            {   43, OutputRoles::BitsPerColorOptionsPreferEfficiencyRole },
            {   44, OutputRoles::BitsPerColorOptionsPreferAccuracyRole },
            {   45, OutputRoles::SharpnessRole },
            {   46, OutputRoles::AutoBrightnessRole },
            {   47, OutputRoles::HdrIccProfileRole },
            {   48, OutputRoles::HdrColorProfileSourceRole },
            {   49, OutputRoles::AbmLevelRole },
        }),
    };
    return QtMocHelpers::metaObjectData<OutputModel, qt_meta_tag_ZN11OutputModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OutputModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11OutputModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11OutputModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11OutputModelE_t>.metaTypes,
    nullptr
} };

void OutputModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OutputModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionChanged(); break;
        case 1: _t->sizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OutputModel::*)()>(_a, &OutputModel::positionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputModel::*)()>(_a, &OutputModel::sizeChanged, 1))
            return;
    }
}

const QMetaObject *OutputModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OutputModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11OutputModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int OutputModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OutputModel::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OutputModel::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
